@@ -35,6 +35,7 @@
 #'          lv_final_estimator = "miiv",
 #'          lasso_model_crit    = NULL, 
 #'          hybrid = FALSE,
+#'          VAR = FALSE,
 #'          dir_prop_cutoff =0)
 #' @param data The path to the directory where the data files are located,
 #' or the name of the list containing each individual's time series. Each file
@@ -148,6 +149,8 @@
 #' indicate the model selection criterion to use for model selection: 'bic' (select on BIC), 'aic', 'aicc', 'hqc', 'cv' (cross-validation). 
 #' @param hybrid Logical. If TRUE, enables hybrid-VAR models where both directed contemporaneous paths and contemporaneous 	
 #' covariances among residuals are candidate relations in the search space. Defaults to FALSE.
+#' @param VAR Logical.  If true, VAR models where contemporaneous covariances among residuals are candidate relations in the 
+#' search space.  Defaults to FALSE.
 #' @param dir_prop_cutoff Option to require that the directionality of a relation has to be higher than the reverse direction for a prespecified proportion of indivdiuals.  
 #' @details
 #'  In main output directory:
@@ -254,6 +257,7 @@ gimmeSEM <- gimme <- function(data             = NULL,
                               lv_final_estimator = "miiv",
                               lasso_model_crit = NULL, 
                               hybrid = FALSE,
+                              VAR = FALSE,
                               dir_prop_cutoff = 0){          # c("miiv", "pml")
   
   # satisfy CRAN checks
@@ -284,6 +288,12 @@ gimmeSEM <- gimme <- function(data             = NULL,
                 " Please ensure that ar=TRUE if hybrid=TRUE."))
   }
   
+  #Error check for var
+  if(VAR & !ar){
+    stop(paste0("gimme ERROR: Autoregressive paths have to be open for var-gimme.",
+                " Please ensure that ar=TRUE if var=TRUE."))
+  }
+  
    sub_membership = NULL
    
    # if !is.null(lasso_model_crit)
@@ -350,7 +360,9 @@ gimmeSEM <- gimme <- function(data             = NULL,
                        lv_estimator         = lv_estimator,
                        lv_scores            = lv_scores,
                        lv_miiv_scaling      = lv_miiv_scaling,
-                       ms_allow             = ms_allow)
+                       ms_allow             = ms_allow,
+                       hybrid               = hybrid,
+                       VAR                  = VAR)
 
   
   #Error Check for Confirm Subgroup Labels
@@ -384,11 +396,18 @@ gimmeSEM <- gimme <- function(data             = NULL,
   )
 
   if(!hybrid){
-    elig_paths   = dat$candidate_paths
-  } else{
-    elig_paths   = c(dat$candidate_paths, dat$candidate_corr)
+    elig_paths = dat$candidate_paths
+  }else{
+    elig_paths = c(dat$candidate_paths, dat$candidate_corr)
   }
   
+  if(VAR){
+    dat$candidate_paths <- grep("*lag", dat$candidate_paths, value = TRUE)
+    elig_paths = c(dat$candidate_paths, dat$candidate_corr)
+  }
+  
+
+
   grp_hist  <- search.paths(
     base_syntax    = dat$syntax,
     fixed_syntax   = NULL,
